#
# spec file for package iniparser
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# if bumping this, also update baselibs.conf
%define sonum 4
%define unity_version 2.6.1
Name:           iniparser
Version:        4.2.6
Release:        1.1
Summary:        Library to parse ini files
License:        MIT
Group:          System/Libraries
URL:            https://gitlab.com/iniparser/iniparser
Source:         https://gitlab.com/iniparser/iniparser/-/archive/v%{version}/%{name}-v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source2:        https://github.com/ThrowTheSwitch/Unity/archive/refs/tags/v%{unity_version}.tar.gz#/unity-%{unity_version}.tar.gz
Source3:        baselibs.conf
# PATCH-FIX-UPSTREAM - https://gitlab.com/iniparser/iniparser/-/merge_requests/171
Patch:          fix-tests.patch
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
# Test requires
BuildRequires:  ruby

%description
Libiniparser offers parsing of ini files from the C level.

%define libiniparser_name libiniparser%{sonum}

%package -n %{libiniparser_name}
Summary:        Library to parse ini files
Group:          System/Libraries

%description -n %{libiniparser_name}
Libiniparser offers parsing of ini files from the C level.

This package includes the libiniparser%{sonum} library.

%package -n libiniparser-devel
Summary:        Libraries and Header Files to Develop Programs with libiniparser Support
Group:          Development/Libraries/C and C++
Requires:       %{libiniparser_name} = %{version}

%description -n libiniparser-devel
This package contains the static libraries and header files needed to
develop programs which make use of the libiniparser programming
interface.

The libiniparser offers parsing of ini files from the C level.	See a
complete documentation in HTML format, from the
%{_docdir}/libiniparser-devel directory open the file
html/index.html with any HTML-capable browser.

Libraries and Header Files to Develop Programs with iniparser Support.

%prep
%autosetup -p1 -b2 -n %{name}-v%{version}

%build
%cmake \
	-DBUILD_STATIC_LIBS:BOOL=OFF \
	-DBUILD_DOCS:BOOL=ON \
	-DCMAKE_INSTALL_DOCDIR:PATH=%{_docdir}/libiniparser-devel \
	-DBUILD_TESTING:BOOL=ON \
	-DFETCHCONTENT_SOURCE_DIR_UNITY:PATH=%{_builddir}/Unity-%{unity_version}
%cmake_build

%install
%cmake_install

%check
%ctest

%post -n %{libiniparser_name} -p /sbin/ldconfig
%postun -n %{libiniparser_name} -p /sbin/ldconfig

%files -n %{libiniparser_name}
%{_libdir}/*.so.*

%files -n libiniparser-devel
%doc html/
%{_libdir}/*.so
%{_libdir}/cmake/%{name}
%{_libdir}/cmake/unity
%{_libdir}/pkgconfig/%{name}.pc
%{_includedir}/%{name}
%{_includedir}/unity
%exclude %{_libdir}/*.a

%changelog
* Thu Jan 23 2025 Yunus Acar <yunus.acar@suse.com>
- Add fix-tests.patch: Makes the tests work with the "offline"
  CMake option (FETCHCONTENT_SOURCE_DIR_UNITY)
- Drop iniparser_remove_rpath.patch: Not needed anymore because of
  the switch to CMake
- Update to version 4.2.6:
  * CVE-2025-0633 (bsc#1237377)
    Fix heap overflow in iniparser_dumpsection_ini()
  * Add test to reproduce heap overflow in
    iniparser_dumpsection_ini()
  * Fix links to FAQ sites in doxygen generated documentation
  * Add packaging status badge to give users and me an overview
  * Enable command line arguments for tests
- Update to version 4.2.5:
  * Fix stack buffer overflow in iniparser dump functions
  * Update doxygen main page, merge it with README and use it as
  * new main page
    Explain how to build documentation as it not build per default
  * Stylize the name iniParser as it used to be done
  * Mention CMake options to prevent them from being overlooked
  * Add build instructions for MinGW
  * Replace outdated installation instructions by link to README
    sections
  * Remove section numbers from README
  * add DESCRIPTION, HOMEPAGE_URL and LANGUAGES in cmake project()
  * Fix MSVC build issues
- Update to version 4.2.4:
  * Fix paths in generated pkgconfig file
- Update to version 4.2.3:
  * Replace our own unit test framework (CuTest) by Unity
  * Do not install tests but make them execute in build directory
  * Build and run tests and examples on Windows CI runner
  * Fix pkgconfig file
- Update to version 4.2.2:
  * add CMake Support
  * update README
  * add Gitlab CI configuration
  * This release makes iniparser-meta obsolete.
* Wed May 15 2024 Michal Suchanek <msuchanek@suse.com>
- Update to version 4.2.1
  * Fix parsing of section names containing whitespace
  * Add support for escaped quotes, semicolon and hash in quoted values
  * Do not close file in iniparser_load_file
  * Add function description to header
  * Add support for loading string/custom streams
  * Update README.md
  * Handle potential calloc failures in dictionary_new
  * Add example showing how to write INI files
  * Add support for uint64_t
  * Fix tests on 32bit
  * Prevent `long int` overflow on 32bit architectures
  * Fail testrun on test failure
  * add NULL check in dictionary_get
  * Fix buffer overflow from sprintf
- Remove patches merged upstream
  * Fail-testrun-on-test-failure.patch
  * Fix-buffer-overflow-from-sprintf.patch
  * Fix-tests-on-32bit.patch
  * handle-null-return-getstring.patch
* Fri Jun  2 2023 Antonio Teixeira <antonio.teixeira@suse.com>
- Add handle-null-return-getstring.patch (bsc#1211889)
  CVE-2023-33461: NULL pointer dereference in iniparser_getboolean()
* Wed Aug 24 2022 Michal Suchanek <msuchanek@suse.com>
- Add fixes since 4.1
  + Fail-testrun-on-test-failure.patch
  + Fix-buffer-overflow-from-sprintf.patch
- Fix tests failing on 32bit architectures
  + Fix-tests-on-32bit.patch
* Sat Nov 11 2017 aavindraa@gmail.com
- Update to 4.1 (stable release)
  + For full change set, see:
    https://github.com/ndevilla/iniparser/compare/b1c4ac6f...v4.1
- Cleanup with spec-cleaner
- Rebase iniparser_remove_rpath.patch
- so number bumped from 0 to 1 per upstream policy
* Sat Jun 27 2015 lmuelle@suse.com
- Update to git snapshot 20150605 b1c4ac6f
  + Use the same xstrdup implementation for both source file
  + allocate memory for string termination
  + Add travis.yml
  + iniparser_getseckeys doesn't return a malloc ptr anymore
  + One more static + whitespace cleanup
  + Prevent negative array index access when a line solely consists of
    newlines and spaces
  + Made strstrip() static
- Remove libiniparser from baselibs.conf
* Thu Jun 19 2014 lmuelle@suse.com
- Update to git snapshot 20140619 c5beb80a
  + Fix coverity issues
  + Fix resource leaks
  + Modify to build unbounded keys & values from multi-line input
  + Fix crash with crafted ini files
  + Makefile fixes: Library build, targets
  + Prevent compiler warning when compiling for 64 bit
  + Build system improvements
- Update iniparser_remove_rpath.patch
* Mon Mar 17 2014 lmuelle@suse.com
- Remove superfluous obsoletes *-64bit in the ifarch ppc64 case; (bnc#437293).
* Fri Jun  7 2013 lmuelle@suse.com
- Include LICENSE file from the source tar ball.
* Tue Jun  5 2012 lmuelle@suse.com
- Define library name and use it instead of libiniparser0.
* Sun Jun  3 2012 lmuelle@suse.com
- Use the unversioned libiniparser name on pre-11.2 systems only.
* Sun Jun  3 2012 lmuelle@suse.com
- Define library name and use it instead of libiniparser0.
- Remove unused debug_package_requires define.
* Sat Apr 21 2012 lars@samba.org
- Update to version 3.1.
  + Const'ified input string arguments
- Update to version 3.0.
  + Single function to set values in a dict: iniparser_set()
  + Bug corrected for lines containing only \n
  + Enhanced documentation
  + C++ nonsense removed
* Thu Dec 17 2009 jengelh@medozas.de
- add baselibs.conf as a source
- enable parallel building
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Thu Nov 27 2008 ro@suse.de
- update baselibs.conf
* Thu Aug 28 2008 anschneider@suse.de
- create packages following the shlib policy
- build only the shared library
* Wed Aug 20 2008 meissner@suse.de
- use RPM_OPT_FLAGS, libiniparser.a can be 644
* Mon May  5 2008 anschneider@suse.de
- build without rpath
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Thu Dec 27 2007 crrodriguez@suse.de
- fix library-without-ldconfig* errors
* Sun May 27 2007 lmuelle@suse.de
- Update to version 2.17.
  + Apply some const and fix c++ warnings.
  + Merge revision 19928 from samba.org subversion.
  + Applied patches to the Makefile to build a shared library.
* Sun May 20 2007 lmuelle@suse.de
- Remove requires on release from devel packages.
* Tue Sep 26 2006 gd@suse.de
- Update to version 2.15
  - documentation fixes
* Tue Apr 11 2006 lmuelle@suse.de
- Inital SuSE RPM.
